@@ -7,7 +7,7 @@
 
 #include "ghost.h"
 
-#include <KgDifficulty>
+#include <KGameDifficulty>
 #include <QPointF>
 #include <QRandomGenerator>
 #include <cstdlib>
@@ -106,7 +106,7 @@ void Ghost::updateMove()
                 m_ySpeed = -m_ySpeed;
             } else if ((m_xSpeed != 0 && m_xSpeed != directionsList[nb].x())
                        || (m_ySpeed != 0 && m_ySpeed != directionsList[nb].y())) { // If the chosen direction isn't forward
-                // We move the ghost on the center of the cell and update the directions
+                // We move the ghost in the center of the cell and update the directions
                 moveOnCenter();
                 m_xSpeed = directionsList[nb].x();
                 m_ySpeed = directionsList[nb].y();
@@ -217,14 +217,14 @@ void Ghost::doActionOnCollision(Kapman *)
 void Ghost::initSpeedInc()
 {
     // Ghosts speed increase when level up
-    switch ((int)Kg::difficultyLevel()) {
-    case KgDifficultyLevel::Easy:
+    switch ((int)KGameDifficulty::globalLevel()) {
+    case KGameDifficultyLevel::Easy:
         m_speedIncrease = Character::LOW_SPEED_INC;
         break;
-    case KgDifficultyLevel::Medium:
+    case KGameDifficultyLevel::Medium:
         m_speedIncrease = Character::MEDIUM_SPEED_INC;
         break;
-    case KgDifficultyLevel::Hard:
+    case KGameDifficultyLevel::Hard:
         m_speedIncrease = Character::HIGH_SPEED_INC;
         break;
     }
